FlsaStatus

Enum FlsaStatus 

pub enum FlsaStatus {
    Exempt,
    Nonexempt,
    Owner,
    SalariedNonexempt,
    Noop,
    FallthroughString,
}
The FLSA status for this compensation. Salaried (‘Exempt’) employees are paid a fixed salary every pay period. Salaried with overtime (‘Salaried Nonexempt’) employees are paid a fixed salary every pay period, and receive overtime pay when applicable. Hourly (‘Nonexempt’) employees are paid for the hours they work, and receive overtime pay when applicable. Owners (‘Owner’) are employees that own at least twenty percent of the company.

Variants



Exempt



Nonexempt



Owner



SalariedNonexempt



Noop



FallthroughString

Implementations