pub struct PostEmployeeBenefitsRequest {Show 13 fields
pub active: Option<bool>,
pub catch_up: Option<bool>,
pub company_benefit_id: f64,
pub company_contribution: String,
pub company_contribution_annual_maximum: String,
pub contribute_as_percentage: Option<bool>,
pub coverage_amount: String,
pub coverage_salary_multiplier: String,
pub deduct_as_percentage: Option<bool>,
pub deduction_reduces_taxable_income: Option<DeductionReducesTaxableIncome>,
pub employee_deduction: String,
pub employee_deduction_annual_maximum: String,
pub limit_option: String,
}Expand description
Fields
active: Option<bool>catch_up: Option<bool>company_benefit_id: f64The ID of the employee in Gusto.
company_contribution: Stringcompany_contribution_annual_maximum: Stringcontribute_as_percentage: Option<bool>coverage_amount: Stringcoverage_salary_multiplier: Stringdeduct_as_percentage: Option<bool>deduction_reduces_taxable_income: Option<DeductionReducesTaxableIncome>Whether the employee deduction reduces taxable income or not. Only valid for Group Term Life benefits. Note: when the value is not “unset”, coverage amount and coverage salary multiplier are ignored.
employee_deduction: Stringemployee_deduction_annual_maximum: Stringlimit_option: StringTrait Implementations
Sourceimpl Clone for PostEmployeeBenefitsRequest
impl Clone for PostEmployeeBenefitsRequest
Sourcefn clone(&self) -> PostEmployeeBenefitsRequest
fn clone(&self) -> PostEmployeeBenefitsRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PostEmployeeBenefitsRequest
impl Debug for PostEmployeeBenefitsRequest
Sourceimpl<'de> Deserialize<'de> for PostEmployeeBenefitsRequest
impl<'de> Deserialize<'de> for PostEmployeeBenefitsRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PostEmployeeBenefitsRequest
impl JsonSchema for PostEmployeeBenefitsRequest
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PostEmployeeBenefitsRequest
impl PartialEq for PostEmployeeBenefitsRequest
Sourcefn eq(&self, other: &PostEmployeeBenefitsRequest) -> bool
fn eq(&self, other: &PostEmployeeBenefitsRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for PostEmployeeBenefitsRequest