pub struct PostPartnerManagedCompaniesResponse {
pub access_token: String,
pub company_uuid: String,
pub refresh_token: String,
}Expand description
Fields
access_token: Stringcompany_uuid: Stringrefresh_token: StringTrait Implementations
Sourceimpl Clone for PostPartnerManagedCompaniesResponse
impl Clone for PostPartnerManagedCompaniesResponse
Sourcefn clone(&self) -> PostPartnerManagedCompaniesResponse
fn clone(&self) -> PostPartnerManagedCompaniesResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for PostPartnerManagedCompaniesResponse
impl<'de> Deserialize<'de> for PostPartnerManagedCompaniesResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PostPartnerManagedCompaniesResponse
impl JsonSchema for PostPartnerManagedCompaniesResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PostPartnerManagedCompaniesResponse
impl PartialEq for PostPartnerManagedCompaniesResponse
Sourcefn eq(&self, other: &PostPartnerManagedCompaniesResponse) -> bool
fn eq(&self, other: &PostPartnerManagedCompaniesResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for PostPartnerManagedCompaniesResponse