pub struct PutCompanyBankAccountsVerifyRequest {
pub deposit_1: f64,
pub deposit_2: f64,
}Expand description
Fields
deposit_1: f64deposit_2: f64Trait Implementations
Sourceimpl Clone for PutCompanyBankAccountsVerifyRequest
impl Clone for PutCompanyBankAccountsVerifyRequest
Sourcefn clone(&self) -> PutCompanyBankAccountsVerifyRequest
fn clone(&self) -> PutCompanyBankAccountsVerifyRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for PutCompanyBankAccountsVerifyRequest
impl<'de> Deserialize<'de> for PutCompanyBankAccountsVerifyRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PutCompanyBankAccountsVerifyRequest
impl JsonSchema for PutCompanyBankAccountsVerifyRequest
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PutCompanyBankAccountsVerifyRequest
impl PartialEq for PutCompanyBankAccountsVerifyRequest
Sourcefn eq(&self, other: &PutCompanyBankAccountsVerifyRequest) -> bool
fn eq(&self, other: &PutCompanyBankAccountsVerifyRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for PutCompanyBankAccountsVerifyRequest