pub struct PutCompanyJobApplicantRequest {
pub date_of_birth: Option<NaiveDate>,
pub email: String,
pub first_name: String,
pub job_title: String,
pub last_name: String,
pub onboarding_person_type: Option<OnboardingPersonType>,
pub phone: String,
pub send_offer: Option<bool>,
pub start_date: Option<NaiveDate>,
}Expand description
Fields
date_of_birth: Option<NaiveDate>email: Stringfirst_name: Stringjob_title: Stringlast_name: Stringonboarding_person_type: Option<OnboardingPersonType>Must be “Employee” if send_offer is set to true.
phone: Stringsend_offer: Option<bool>start_date: Option<NaiveDate>Trait Implementations
Sourceimpl Clone for PutCompanyJobApplicantRequest
impl Clone for PutCompanyJobApplicantRequest
Sourcefn clone(&self) -> PutCompanyJobApplicantRequest
fn clone(&self) -> PutCompanyJobApplicantRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for PutCompanyJobApplicantRequest
impl<'de> Deserialize<'de> for PutCompanyJobApplicantRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PutCompanyJobApplicantRequest
impl JsonSchema for PutCompanyJobApplicantRequest
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PutCompanyJobApplicantRequest
impl PartialEq for PutCompanyJobApplicantRequest
Sourcefn eq(&self, other: &PutCompanyJobApplicantRequest) -> bool
fn eq(&self, other: &PutCompanyJobApplicantRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for PutCompanyJobApplicantRequest